@@ -3,7 +3,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 sub new {
     return bless {}, shift;
@@ -18,17 +18,18 @@ sub mock {
 
     $sub = "main::$sub" if $sub !~ /::/;
 
+    my $fake;
+
     if (! exists &$sub){
-        die "subroutine specified is not valid";
+        $fake = 1;
+        warn "\n\nWARNING!: we've mocked a non-existent subroutine. " .
+             "the specified sub does not exist.\n\n";
     }
 
+    $self->_check_side_effect($self->{side_effect});
+
     $self->{name} = $sub;
-
-    # side_effect must be a legit code reference
-
-    if (defined $self->{side_effect} && ref $self->{side_effect} ne 'CODE'){
-        die "side_effect parameter must be a code reference";
-    }
+    $self->{orig} = \&$sub if ! $fake;
 
     my $called;
 
@@ -48,6 +49,24 @@ sub mock {
     }
     return $self;
 }
+sub unmock {
+    my $self = shift;
+    my $sub = $self->{name};
+
+    {
+        no strict 'refs';
+        no warnings 'redefine';
+
+        if (defined $self->{orig}) {
+            *$sub = \&{ $self->{orig} };
+            delete $self->{orig};
+        }
+        else {
+            undef *$sub;
+        }
+    }
+    $self->reset;
+}
 sub called {
     return shift->called_count ? 1 : 0;
 }
@@ -61,9 +80,20 @@ sub name {
     return shift->{name};  
 }
 sub reset {
-    my $self = shift;
     for (qw(side_effect return_value called called_count called_with)){
-        delete $self->{$_};
+        delete $_[0]->{$_};
+    }
+}
+sub return_value {
+    $_[0]->{return_value} = $_[1];
+}
+sub side_effect {
+    $_[0]->_check_side_effect($_[1]);
+    $_[0]->{side_effect} = $_[1];
+}
+sub _check_side_effect {
+    if (defined $_[1] && ref $_[1] ne 'CODE') {
+        die "side_effect parameter must be a code reference";
     }
 }
 sub _end {}; # vim fold placeholder
@@ -118,10 +148,22 @@ Mock::Sub - Mock module, package, object and standard subroutines, with unit tes
 
     my @args = $foo->called_with;
 
+    # add/change/remove the side_effect after instantiation
+
+    $foo->side_effect(sub {die;});
+
+    # add/change/remove the return_value after instantiation
+
+    $foo->return_value(50);
+
     # reset the mocked sub for re-use within the same scope
 
     $foo->reset;
 
+    # restore original functionality to the sub
+
+    $foo->unmock;
+
 
 =head1 DESCRIPTION
 
@@ -219,6 +261,11 @@ it does: C<sub {...; undef; }>.
 
 =back
 
+=head2 C<unmock>
+
+Restores the original functionality back to the sub, and runs C<reset()> on
+the object.
+
 =head2 C<called>
 
 Returns true if the sub being mocked has been called.
@@ -235,10 +282,21 @@ Returns an array of the parameters sent to the subroutine.
 
 Returns the full name of the sub being mocked, as entered into C<mock()>.
 
+=head2 C<side_effect($cref)>
+
+Add (or remove) a side effect after instantiation. Same rules apply here as
+they do for the C<side_effect> parameter.
+
+=head2 C<return_value>
+
+Add (or change, delete) the mocked sub's return value after instantiation.
+Takes a single parameter, which can be anything you want it to be. Send in
+C<undef> to remove a previously set value.
+
 =head2 C<reset>
 
 Resets the functional parameters (C<return_value>, C<side_effect>), along
-with C<called()> and C<called_count> back to undef/untrue.
+with C<called()> and C<called_count()> back to undef/false.
 
 =head1 NOTES
 
